#
# spec file for package python-python-gvm
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-gvm
Version:        24.8.0
Release:        2.2
Summary:        Library to communicate with remote servers over GMP or OSP
License:        GPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/greenbone/python-gvm
Source:         https://files.pythonhosted.org/packages/source/p/python_gvm/python_gvm-%{version}.tar.gz
# PATCH-FIX-OPENSUSE opensuse-fix-tests-1-core.patch -- bsc#1233398
# Fix tests running with 1 core in VM
Patch:          opensuse-fix-tests-1-core.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-lxml >= 4.5.0
Requires:       python-paramiko >= 2.7.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module lxml >= 4.5.0}
BuildRequires:  %{python_module paramiko >= 2.7.1}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
The Greenbone Vulnerability Management Python API library python-gvm is a
collection of APIs that help with remote controlling a Greenbone Security
Manager (GSM) appliance and its underlying Greenbone Vulnerability Manager
(GVM). The library essentially abstracts accessing the communication protocols
Greenbone Management Protocol (GMP) and Open Scanner Protocol (OSP).

%prep
%autosetup -p1 -n python_gvm-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
# Remove tests from sitelib
%python_expand rm -rf %{buildroot}%{$python_sitelib}/tests
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_pretty_print needs pontos, which we don't have
rm tests/xml/test_pretty_print.py
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/gvm
%{python_sitelib}/python_gvm*

%changelog
* Mon Nov 25 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add opensuse-fix-tests-1-core.patch custom patch to fix tests
  running in OBS with limited resources, running on 1-core-VM.
  bsc#1233398
* Wed Nov 13 2024 Markéta Machová <mmachova@suse.com>
- Update to 24.8.0
  * Drop typing_extensions dependency. Drop the use of the Self component
    from typing_extensions and use the typing library instead
  * 24.6 contains a major internal refactoring and drops support for GMP < 22.4.
  * Use base enum class for most enums in python-gvm
  * Enable "security-and-quality" quereis for CodeQL
  * Many more changes, see upstream changelog
* Tue Aug  1 2023 Markéta Machová <mmachova@suse.com>
- Update to 23.5.0
  * Allow to query host and os details
  * Add linting for Python 3.11
  * Remove console output from ssh connection tests
  * Fasten the CI by using a short timeout for SSH connection tests
  * CI parameter to SSH connection for automatic skip of user input
  * Set TLS minimum version, avoid version protocols
* Mon Mar  6 2023 Dirk Müller <dmueller@suse.com>
- update to 23.2.0:
  * Use universal release action, not python specific d7d4ea59
  * Add workaround for non-standard SSH ports (#925) 6a8c2f19
  * Format workflows, update actions and support Python 3.11
  * Format workflows, update actions and support Python 3.11
  * Improve error output in case of unix socket connection issues
  * Start to deploy the python-gvm docs at github pages too
    98ac0c56
  * Remove hardcoded ignore_pagination from get_reports (#821)
  * Update links and terms in README and docs 6bd8c78e
  * Fix setting the port for the SSH connection #818 9784cf52
  * Improve installation chapter d1d602e4
  * Use furo theme for sphinx based docs for improved navigation
  * Use sphinx directly for typehints in API docs f707efdf
  * Update gvmd socket location to /run/gvmd/gvmd.sock 4a0f1706
  * Adjust PR template for using Conventional Commits 6287140d
  * Update lastest Gmp class to 22.4 44e85036
  * Add missing API docs for GMP 22.4 class (#804) fb69ec30
  * Use isort for sorting Python import automatically e61b9ac5
  * OSP Scanner is deprecated with 22.04 (#789) 1cf0559a
  * Normalize all strings with black fbf0083d
  * Check port in overrides/notes like in gvmd 905e85ab
  * severity values of '0' have not been passed to gvmd cd4e0b44
    gvm/compare/22.6.1.dev1...22.6.1
  * Don't mention ALLINFO in the get_info_list method dc288185
  * Deprecate ifaces and icafes allow_parameters in user commands
  * Rename GMP 21.10 to GMP 22.04 [#691] f5ef7672
  * Unwrap SSL socket before closing transport socket. (#737)
  * Ensure that connection is closed when using context manager
  * Added support for PEP-561 c354da8
  * Adding the structure for GVM 21.10. [#575] fe203be
  * The types dict could not be accessed via dotted notation
    previously, this fix should make it possible. 0111cd9
  * Adding the `types` attribute back to the `Gmp` classes [#568]
    d04aea4
  * For SSH Connections: Reject unknown hosts, ask user if he
    wants to connect to unknown remote host and ask user if he
    wants to add the host to `known_hosts` #486
* Sat Jun  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 21.5.0
  * Dropped support for GMP v7, v8 and v9!
  * Introduced new explicit API calls for SecInfo: get_nvt(),
    get_nvt_list(), get_cpe(), get_cpe_list(), get_cve(),
    get_cve_list(), get_cert_bund_advisory(),
    get_cert_bund_advisory_list(), get_dnf_cert_advisory(),
    get_dnf_cert_advisory_list(), get_oval_definition(),
    get_oval_definition_list().
  Changed
  * Splitted up get_preference(s) into get_nvt_preference(s) and
    get_scan_config_preference(s).
  * Improved and changed help(): Introduced HelpFormat Enum,
    changed format parameter to help_format using HelpFormat,
    changed help_type to brief and bool, as it only has two
    options (default and brief).
  * Changed filter to filter_string in getter functions.
  * API changes: get_setting(s) -> get_user_setting(s),
    modify_setting -> modify_user_setting. #472
  * Changed all API calls for _config to _scan_config to match
    other Greenbone components. #465
  * Split up get_asset(s) into get_host(s) and
    get_operating_system(s). #459
  * Split up delete_asset into delete_host and
    delete_operating_system. #459
  * Split up modify_asset into modify_host and
    modify_operating_system. #459
  * Deleted AssetType. It is not required anymore. #459
  * Changed the API calls get_nvt() and get_nvts() to
    get_scan_config_nvt() and get_scan_config_nvts(). #456
  * Splitted up the GmpMonolith class
  * Moved helper functions from gmp to utils. The response XML
    will not be recovered by the parser anymore! #442
  Removed
  * Removed sync_feed, sync_scap, and sync_cert calls. #472
  * Removed TimeUnit. It was used for schedules before iCal and
    is not required anymore. #469
  * Removed Gmpv214Mixin. #467
  * Remove support of delete host/operating system by a report.
  * Remove deprecated make_unique parameter from Targets. #446
  * Removed deprecated Agents completely. #441
  * Dropped support for GMP v7, v8 and v9! The oldest usable
    GMP version is 20.8
* Mon Apr 26 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 21.1.4
  * get_feed can also be requested with GVMD_DATA for 20.08 and
    newer, added GVMD_DATA to the FeedType and updated API call.
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 21.1.3
  Added
  * Added protocol version "next" and GMP 21.04 doc.
  Fixed
  * Add missing ReportFormatType to GMP 21.04.
- Update to version 21.1.2
  Added
  * Added allow_simultaneous_ips param for targets.
  Removed
  * dropped the GMP Scanner (4) from ScannerTypes for v21.4.
  Fixed
  * removing timeout from get_nvt().
  * Add ReportFormatType and get_report_format_id_from_string to
    latest.py, so it is usable with import gvm.protcols.latest.
  * Fixing import_report() for v9 and v20.8 and newer, removed
    the task_name and task_comment parameters, that do not work
    anymore.
- Update to version 21.1.1
  Fixed
  * Fixed release issues, through rerelease.
- Update to version 21.1.0
  * Deprecated
  * Dropped Python 3.5 and Python 3.6 support. Python 3.7+ is
    required now.
  Fixed
  * Add missing types and functions to "latest" GMP.
* Thu Nov  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.11.0
  Added
  * Added clone_report_format() and import_report_format()
  * Added the get_x_from_string() functions to latest
  * Added the ReportFormatType that can be used instead of a
    report_format_id.
  * Added tests for constructor of SSHConnection, TLSConnection,
    UnixSocketConnection and GvmConnection.
  Fixed
  * Corrected seconds_active parameter to days_active for notes
    and overrides.
  * Fixed SSHConnection throws TypeError if port is None.
  * Fixed GvmConnection timeout set to None if None is passed.
  * Fixed TLSConnection values set to None instead of default
    values when None is passed for these values.
  * Fixed UnixSocketConnection values set to None instead of
    default when None is passed for these values.
* Sun Oct 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.9.1
  Added
  * Added modify_config_set_name. #295
  * Added logic to accept the new AlertEvents TICKET_RECEIVED,
    ASSIGNED_TICKET_CHANGED and OWNED_TICKET_CHANGED and the new
    Condition SEVERITY_CHANGED.
  * Added create_config_from_osp_scanner. #298
  Changed
  * Added the details parameter to get_tls_certificate and
    get_tls_certificates.
  * Added the comment parameter to create_config.
  Fixed
  * Fix ScannerType check for newer protocols.
* Thu Sep 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.9.0
  Changed
  * Added the tasks parameter to get_config().
  * Renamed no_details to details in get_reports() so it is
    uniform with all the other calls.
  Fixed
  * Force garbage clean up when disconnect.
* Tue Sep  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.8.1
  Added
  * Added AlertMethods: Alemba vFire, Tippingpoint SMS
  * Added AlertConditions: Error, SeverityChanged
  * Added AlertEvents: Assigned ticket changed, Owned ticket
    changed.
  Changed
  * pretty_print() has a new argument that can optionally handle a
    file. The output is redirected to this file. default is
    sys.stdout, as it is for build-in print().
  Fixed
  * ARP_PING is now a field of AliveTypes, the old APR_PING name
    is still available.
* Sat Aug 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to versin 20.8.0
  Added
  * Added support for GMP 20.08
  Changed
  * Refactored Gmp classes into mixins.
  Fixed
  * Require method and condition arguments for modify_alert with
    an event.
  * Add SEVERITY_AT_LEAST to get_alert_condition_from_string.
* Tue Aug 11 2020 Martin Hauke <mardnh@gmx.de>
- Use %%pytest for running the unittest-based testsuite
* Tue Aug 11 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.6.0
